<?php
//==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>
//
// Ajax Poll Admin v3.18 [ FREE TRIAL VERSION ]
// Copyright (c) phpkobo.com ( http://www.phpkobo.com/ )
// Email : admin@phpkobo.com
// ID : APADM-318-FTV
// URL : http://www.phpkobo.com/ajax-poll-admin
//
//==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<

//----------------------------------------------------------------
// CPollItem
//----------------------------------------------------------------
class CPollItem
{
	function setup( $sys, $prt, $name )
	{
		//-- pointers
		$this->sys =& $sys;
		$this->prt =& $prt;
		$this->name = $name;

		//-- attributes
		$this->_attr_ = array();

		//-- count
		$this->cnt = 0;
	}

	function attr( $key, $val = null )
	{
		if ( $this->checkNullItem( $msg ) ) return $msg;

		if ( is_null( $val ) )
		{
			if ( isset( $this->_attr_[$key] ) )
				return $this->_attr_[$key];
			else
				return $this->prt->getUnknownAttr( $key );
		}
		else
		{
			$this->_attr_[$key] = $val;
		}
	}

	function getName()
	{
		if ( $this->checkNullItem( $msg ) ) return $msg;

		return $this->name;
	}

	function getCount()
	{
		return $this->cnt;
	}

	function getPercent( $precision = 0 )
	{
		$total = $this->prt->getTotal();
		if ( $total == 0 )
			$v = 0;
		else
			$v = ( 100 * $this->getCount() ) / $total;
		$v = round( $v, $precision );
		$v = sprintf( "%01.{$precision}f", $v );
		return $v;
	}

	function getWRatio() {
		$max_count = $this->prt->getMaxCount();
		if ( $max_count == 0 ) { return 0; }
		return round( $this->getCount() / $max_count, 2 );
	}

	//----------------------------------------------------------------
	// helper functions
	//----------------------------------------------------------------
	function setCount( $cnt )
	{
		if ( !$this->isInteger( $cnt ) ) $cnt = 0;
		$this->cnt = intval( $cnt );
	}

	function incCount( $d = 1 )
	{
		$this->cnt += $d;
	}

	function checkNullItem( &$msg )
	{
		if ( is_null( $this->name ) )
		{
			$msg = "<span style='color:red;'>Item not declared</span>";
			return true;
		}
		else
			return false;
	}

	function isInteger( $v )
	{
		if ( strlen( $v ) == 0 ) return false;
		if ( !is_numeric( $v ) ) return false;
		if ( doubleval( $v ) - intval( $v ) != 0 ) return false;
		return true;
	}

	function isVoted() {
		return $this->prt->hasVoted( $this->getName() );
	}


}

//----------------------------------------------------------------
// CPoll
//----------------------------------------------------------------
class CPoll
{
	//----------------------------------------------------------------
	// setup
	//----------------------------------------------------------------
	function setup( $sys, $prt, $poll_id )
	{
		$this->poll_id = $poll_id;

		//-- pointers
		$this->sys =& $sys;
		$this->prt =& $prt;

		//-- attributes
		$this->_attr_ = array();

		//-- poll items
		$this->items = array();
		$this->item_key_list = array();
		$this->item_key_idx = 0;

		//-- dummy item
		$this->dummy_item = new CPollItem();
		$this->dummy_item->setup( $sys, $this, null );

		//-- default max width
		$this->setMaxWidth( 100 );

		return true;
	}

	function getFolderUrl() {
		$skin = $this->attr( 'skin_type' );
		$url = dirname($this->sys->url_app_root) . "/skins/{$skin}/";
		return $url;
	}

	//----------------------------------------------------------------
	// tprop
	//----------------------------------------------------------------
	function tprop( $key, $val = null )
	{
		if ( is_null( $val ) )
		{
			if ( isset( $this->_attr_['tprop'][$key] ) )
				return $this->_attr_['tprop'][$key];
			else
				return '';
		}
		else
		{
			$this->_attr_['tprop'][$key] = $val;
		}
	}

	//----------------------------------------------------------------
	// attr
	//----------------------------------------------------------------
	function attr( $key, $val = null )
	{
		if ( is_null( $val ) )
		{
			if ( isset( $this->_attr_[$key] ) )
				return $this->_attr_[$key];
			else
				return $this->getUnknownAttr( $key );
		}
		else
		{
			$this->_attr_[$key] = $val;
		}
	}

	//----------------------------------------------------------------
	// getUnknownAttr
	//----------------------------------------------------------------
	function getUnknownAttr( $key )
	{
		return "";
		return "<span style='color:red;'>?{$key}?</span>";
	}

	function hasVoted( $name = null ) {
		return $this->prt->checkCkBlock( $name );
	}

	//----------------------------------------------------------------
	// getTotal
	//----------------------------------------------------------------
	function getTotal()
	{
		return $this->total;
	}

	//----------------------------------------------------------------
	// setMaxWidth
	//----------------------------------------------------------------
	function setMaxWidth( $max_width )
	{
		if ( $max_width < 0 )
		{
			$this->max_width = 0;
		}
		else
		{
			$this->max_width = $max_width;
		}
	}

	//----------------------------------------------------------------
	// getMaxWidth
	//----------------------------------------------------------------
	function getMaxWidth()
	{
		return $this->max_width;
	}

	//----------------------------------------------------------------
	// getMaxCount
	//----------------------------------------------------------------
	function getMaxCount()
	{
		return $this->max_count;
	}

	//----------------------------------------------------------------
	// getNumOfItems
	//----------------------------------------------------------------
	function getNumOfItems()
	{
		return count( $this->items );
	}

	//----------------------------------------------------------------
	// getAllItems
	//----------------------------------------------------------------
	function getAllItems()
	{
		return $this->items;
	}

	//----------------------------------------------------------------
	// getItem
	//----------------------------------------------------------------
	function getItem( $key = null )
	{
		$err_msg = array();

		if ( is_null($key) )
		{
			if ( !isset( $this->item_idx ) )
			{
				$this->item_idx = 0;
			}

			if ( $this->item_idx >= count($this->item_key_list) )
			{
				return $this->dummy_item;
			}
			else
			{
				$key = $this->item_key_list[$this->item_idx];
				$this->item_idx++;
				return $this->items[$key];
			}
		}
		else if ( !isset( $this->items[$key] ) )
		{
			$err_msg[] = "getItem( key ) : Unknown Item Key ({$key})";
		}

		if ( count( $err_msg ) > 0 )
		{
			$this->prt->showErrorMsg( $err_msg );
		}

		return $this->items[$key];
	}

	//----------------------------------------------------------------
	// addItem
	//----------------------------------------------------------------
	function addItem( $key )
	{
		$item = new CPollItem();
		$item->setup( $this->sys, $this, $key );
		$this->items[$key] = $item;
		$this->item_key_list[$this->item_key_idx] = $key;
		$this->item_key_idx++;
		return $item;
	}

	//----------------------------------------------------------------
	// started
	//----------------------------------------------------------------
	function started()
	{
		return !(
			( !empty( $this->_attr_[ 'dt_start' ] ) ) &&
			( strtotime( $this->_attr_[ 'dt_start' ] ) > time() )
		);
	}

	//----------------------------------------------------------------
	// ended
	//----------------------------------------------------------------
	function ended()
	{
		return (
			( !empty( $this->_attr_[ 'dt_end' ] ) ) &&
			( strtotime( $this->_attr_[ 'dt_end' ] ) < time() )
		);
	}

	//----------------------------------------------------------------
	// calcStats
	//----------------------------------------------------------------
	function calcStats()
	{
		$total = 0;
		$max_count = 0;
		foreach( $this->items as $key => $item )
		{
			$count = $item->getCount();
			$total += $count;
			if ( $max_count < $count ) $max_count = $count;
		}
		$this->total = $total;
		$this->max_count = $max_count;
	}

	//----------------------------------------------------------------
	// load
	//----------------------------------------------------------------
	function load( $b_vote = false )
	{
		$db = $this->sys->db;
		$poll_id = $this->poll_id;

		//-- get option count
		$option_cnt = array();
		$table_name = TBL_OPTION;
		$ls = array( "option_id", "cnt" );
		$qc = array(
			"poll_id=" . $db->Sanitize($poll_id) . "",
		);
		$sql = $db->GetSQLSelect( $table_name, $ls, $qc );
		$result = $db->Query( $sql );
		while ( $rs = $db->GetRowA( $result ) )
		{
			$option_cnt[$rs['option_id']] = $rs['cnt'];
		}
		$db->FreeResult( $result );

		//-- options
		foreach( $this->attr('options') as $option )
		{
			$option_id = $option['option_id'];
			$pi = $this->addItem( $option_id );
			$pi->attr( 'label', $option['label'] );
			if ( isset( $option_cnt[$option_id] ) )
			{
				$pi->setCount( $option_cnt[$option_id] );
			}
		}

		//-- add votes
		$answer = $this->sys->iv( 'answer' );
		$answer = $this->attr( 'answer' );

		$answer = json_decode( $answer, true );
		if ( $b_vote && !empty($answer) )
		{
			foreach( $answer as $ans )
			{
				if ( isset( $this->items[$ans] ) )
				{
					$item = $this->items[$ans];
					$cnt = $item->getCount();
					$item->incCount();

					$table_name = TBL_OPTION;
					$fv = array(
						array( "cnt", "cnt+1" )
					);
					$qc = array(
						"option_id = '" . $db->Sanitize($ans) . "'",
					);
					$db->UpdateRecord( $table_name, $fv, $qc );
				}
			}
		}

	}

}

?>